@@ -52,3 +52,25 @@ def retry(func, params: Union[dict, list, tuple], check_func, num=1):
         except Exception as e:
             logging.error(f"error={e}")
     return result
+
+
+def check_value(value, default):
+    if not value:
+        value = default
+    return value
+
+
+def check_or_add_growth_rate(data: List[dict], key, start_growth_rate=None, flag=True):
+    for i, _ in enumerate(data):
+        if i == 0:
+            if start_growth_rate:
+                data[i][key] = start_growth_rate
+            else:
+                data[i][key] = 0
+        else:
+            pre = check_value(data[i - 1].get(key, 0), 0) if data[i - 1].get(key, 0) else 0
+            current = check_value(data[i].get(key, 0), 0) if data[i].get(key, 0) else 0
+            value = float(current - pre) / pre if pre else 0
+            if flag:
+                value = value * 100
+            data[i][key] = value
